@@ -2,6 +2,7 @@ import hashlib
 import logging
 import uuid
 
+from django.conf import settings
 from django.db import transaction
 from django.db.models import UUIDField, CharField, UniqueConstraint, Q
 from django.forms import model_to_dict
@@ -57,7 +58,9 @@ class MessagesManager(CommonTreeGridManager):
 
     @staticmethod
     def get_tracker_bot():
+        settings.LOCKS.acquire('MessagesManager.get_tracker_bot')
         tracker_bot, _ = User.objects.get_or_create(username='tracker_bot', last_name='Бот (Дела)', password='1234567890', props=User.props.bot, deliting=False, editing=False)
+        settings.LOCKS.release('MessagesManager.get_tracker_bot')
         return tracker_bot
 
     @staticmethod
